@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.4.2"
+    version = "1.4.4"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -125,7 +125,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
 
         payload = f"## {custom_keyword}\n\n" if custom_keyword else ""
         payload = f"{payload} > 项目名称: {project.name} \n\n"
-        # payload = f"{payload} > status: {group.status} \n\n"
+        payload = f"{payload} > status: {group.status} \n\n"
         payload = f"{payload} > 告警次数: {group.times_seen} \n\n"
         payload = f"{payload} > 查看详情: <font color=blue>[{group.title}]({issue_link})</font> \n\n"
         payload = f"{payload} > 具体报错: {group.message} \n\n"
@@ -165,19 +165,19 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
             for webhook_url in self.get_webhook_urls(group.project):
                 requests.post(webhook_url, data=json.dumps(data_1), headers=headers)
 
-        if int(group.times_seen) > int(counts):
-            data_2 = {
-                "msgtype": "markdown",
-                "markdown": {
-                    "title": group.title,
-                    "text": payload + '\n\n' + '@' + '@'.join(phone)
-                },
-                "at": {
-                    "atMobiles": notify_user,
-                    "isAtAll": False
-                }
-
-            }
-
-            for webhook_url in self.get_webhook_urls(group.project):
-                requests.post(webhook_url, data=json.dumps(data_2), headers=headers)
+        # if int(group.times_seen) > int(counts):
+        #     data_2 = {
+        #         "msgtype": "markdown",
+        #         "markdown": {
+        #             "title": group.title,
+        #             "text": payload + '\n\n' + '@' + '@'.join(phone)
+        #         },
+        #         "at": {
+        #             "atMobiles": notify_user,
+        #             "isAtAll": False
+        #         }
+        #
+        #     }
+        #
+        #     for webhook_url in self.get_webhook_urls(group.project):
+        #         requests.post(webhook_url, data=json.dumps(data_2), headers=headers)
